@@ -97,6 +97,29 @@ class ClbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def BatchModifyTargetTag(self, request):
+        """BatchModifyTargetTag 接口用于批量修改负载均衡监听器绑定的后端机器的标签。批量修改的资源数量上限为500。本接口为同步接口。<br/>负载均衡的4层和7层监听器支持此接口，传统型负载均衡不支持。
+
+        :param request: Request instance for BatchModifyTargetTag.
+        :type request: :class:`tencentcloud.clb.v20180317.models.BatchModifyTargetTagRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.BatchModifyTargetTagResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BatchModifyTargetTag", params, headers=headers)
+            response = json.loads(body)
+            model = models.BatchModifyTargetTagResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def BatchModifyTargetWeight(self, request):
         """BatchModifyTargetWeight 接口用于批量修改负载均衡监听器绑定的后端机器的转发权重。批量修改的资源数量上限为500。本接口为异步接口，本接口返回成功后需以返回的 RequestID 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。<br/>负载均衡的4层和7层监听器支持此接口，传统型负载均衡不支持。
 
@@ -146,27 +169,26 @@ class ClbClient(AbstractClient):
     def CloneLoadBalancer(self, request):
         """克隆负载均衡实例，根据指定的负载均衡实例，复制出相同规则和绑定关系的负载均衡实例。克隆接口为异步操作，克隆的数据以调用CloneLoadBalancer时为准，如果调用CloneLoadBalancer后克隆CLB发生变化，变化规则不会克隆。
 
-        限制说明：
-        实例属性维度限制
-          仅支持克隆按量计费实例，不支持包年包月实例。
-          不支持克隆未关联实例计费项的 CLB。
-          不支持克隆传统型负载均衡实例和高防 CLB。
-          不支持克隆基础网络类型的实例。
-          不支持克隆 IPv6、IPv6 NAT64 版本以及混绑的实例。
-          个性化配置、重定向配置、安全组默认放通开关的配置将不会被克隆，需重新配置。
-          执行克隆操作前，请确保实例上没有使用已过期证书，否则会导致克隆失败。
-        监听器维度限制
-          不支持克隆监听器为 QUIC 类型和端口段的实例。
-          不支持监听器为 TCP_SSL 的内网型负载均衡的实例。
-          不支持克隆七层监听器没有转发规则的实例。
-          当实例的监听器个数超过50个时，不支持克隆。
-        后端服务维度限制
-          不支持克隆绑定的后端服务类型为目标组和 SCF 云函数的实例。
+        注：查询实例创建状态可以根据返回值中的requestId访问[DescribeTaskStatus](https://cloud.tencent.com/document/product/214/30683)接口
+
+        限制说明
+        实例属性维度限制：
+        - 支持克隆网络计费模式为按量计费与包年包月的实例，包年包月实例克隆后的新实例网络计费模式会转换为按小时带宽计费，其带宽、规格与原实例设置保持一致。
+        - 不支持克隆未关联实例计费项的 CLB。
+        - 不支持克隆传统型负载均衡实例和高防 CLB。
+        - 不支持克隆基础网络类型的实例。
+        - 不支持克隆 Anycast 类型的实例。
+        - 不支持克隆 IPv6 NAT64 版本的实例。
+        - 不支持克隆被封禁或冻结的实例。
+        - 执行克隆操作前，请确保实例上没有使用已过期证书，否则会导致克隆失败。
+        配额维度限制：
+        - 当实例的监听器个数超过 50 个时，不支持克隆。
+        - 当共享型实例的公网带宽上限超过 2G 时，不支持克隆。
 
         通过接口调用：
         BGP带宽包必须传带宽包id
         独占集群克隆必须传对应的参数，否则按共享型创建
-        功能内测中，[申请开通](https://console.cloud.tencent.com/workorder/category?level1_id=6&level2_id=163&source=0&data_title=%E8%B4%9F%E8%BD%BD%E5%9D%87%E8%A1%A1%20CLB&step=1)。
+        功能内测中，请提交 [内测申请](https://cloud.tencent.com/apply/p/1akuvsmyn0g)。
 
         :param request: Request instance for CloneLoadBalancer.
         :type request: :class:`tencentcloud.clb.v20180317.models.CloneLoadBalancerRequest`
@@ -237,7 +259,7 @@ class ClbClient(AbstractClient):
 
     def CreateLoadBalancer(self, request):
         """本接口(CreateLoadBalancer)用来创建负载均衡实例（本接口只支持购买按量计费的负载均衡，包年包月的负载均衡请通过控制台购买）。为了使用负载均衡服务，您必须购买一个或多个负载均衡实例。成功调用该接口后，会返回负载均衡实例的唯一 ID。负载均衡实例的类型分为：公网、内网。详情可参考产品说明中的产品类型。
-        注意：(1)指定可用区申请负载均衡、跨zone容灾(仅香港支持)【如果您需要体验该功能，请通过 [工单申请](https://console.cloud.tencent.com/workorder/category)】；(2)目前只有北京、上海、广州支持IPv6；(3)一个账号在每个地域的默认购买配额为：公网100个，内网100个。
+        注意：(1)可通过 [DescribeResources](https://cloud.tencent.com/document/api/214/70213) 接口查询一个地域的是是否支持创建IPv6实例；(3)一个账号在每个地域的默认购买配额为：公网100个，内网100个。
         本接口为异步接口，接口成功返回后，可使用 DescribeLoadBalancers 接口查询负载均衡实例的状态（如创建中、正常），以确定是否创建成功。
 
         :param request: Request instance for CreateLoadBalancer.
@@ -1317,6 +1339,98 @@ class ClbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def InquiryPriceCreateLoadBalancer(self, request):
+        """InquiryPriceCreateLoadBalancer接口查询创建负载均衡的价格。
+
+        :param request: Request instance for InquiryPriceCreateLoadBalancer.
+        :type request: :class:`tencentcloud.clb.v20180317.models.InquiryPriceCreateLoadBalancerRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.InquiryPriceCreateLoadBalancerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquiryPriceCreateLoadBalancer", params, headers=headers)
+            response = json.loads(body)
+            model = models.InquiryPriceCreateLoadBalancerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def InquiryPriceModifyLoadBalancer(self, request):
+        """InquiryPriceModifyLoadBalancer接口修改负载均衡配置询价。
+
+        :param request: Request instance for InquiryPriceModifyLoadBalancer.
+        :type request: :class:`tencentcloud.clb.v20180317.models.InquiryPriceModifyLoadBalancerRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.InquiryPriceModifyLoadBalancerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquiryPriceModifyLoadBalancer", params, headers=headers)
+            response = json.loads(body)
+            model = models.InquiryPriceModifyLoadBalancerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def InquiryPriceRefundLoadBalancer(self, request):
+        """InquiryPriceRefundLoadBalancer接口查询负载均衡退费价格。
+
+        :param request: Request instance for InquiryPriceRefundLoadBalancer.
+        :type request: :class:`tencentcloud.clb.v20180317.models.InquiryPriceRefundLoadBalancerRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.InquiryPriceRefundLoadBalancerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquiryPriceRefundLoadBalancer", params, headers=headers)
+            response = json.loads(body)
+            model = models.InquiryPriceRefundLoadBalancerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def InquiryPriceRenewLoadBalancer(self, request):
+        """InquiryPriceRenewLoadBalancer接口查询对负载均衡续费的价格，只支持预付费负载均衡续费。
+
+        :param request: Request instance for InquiryPriceRenewLoadBalancer.
+        :type request: :class:`tencentcloud.clb.v20180317.models.InquiryPriceRenewLoadBalancerRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.InquiryPriceRenewLoadBalancerResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("InquiryPriceRenewLoadBalancer", params, headers=headers)
+            response = json.loads(body)
+            model = models.InquiryPriceRenewLoadBalancerResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ManualRewrite(self, request):
         """用户手动配置原访问地址和重定向地址，系统自动将原访问地址的请求重定向至对应路径的目的地址。同一域名下可以配置多条路径作为重定向策略，实现http/https之间请求的自动跳转。设置重定向时，需满足如下约束条件：若A已经重定向至B，则A不能再重定向至C（除非先删除老的重定向关系，再建立新的重定向关系），B不能重定向至任何其它地址。
         本接口为异步接口，本接口返回成功后需以返回的RequestID为入参，调用DescribeTaskStatus接口查询本次任务是否成功。
@@ -1486,6 +1600,7 @@ class ClbClient(AbstractClient):
 
     def ModifyLoadBalancerAttributes(self, request):
         """修改负载均衡实例的属性。支持修改负载均衡实例的名称、设置负载均衡的跨域属性。
+        注意：非带宽上移用户的 CLB 实例必须加入带宽包才可以设置跨域属性。
         本接口为异步接口，接口返回成功后，需以得到的 RequestID 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。
 
         :param request: Request instance for ModifyLoadBalancerAttributes.
@@ -1903,7 +2018,7 @@ class ClbClient(AbstractClient):
     def SetLoadBalancerSecurityGroups(self, request):
         """SetLoadBalancerSecurityGroups 接口支持对一个公网负载均衡实例执行设置（绑定、解绑）安全组操作。查询一个负载均衡实例目前已绑定的安全组，可使用 DescribeLoadBalancers 接口。本接口是set语义，
         绑定操作时，入参需要传入负载均衡实例要绑定的所有安全组（已绑定的+新增绑定的）。
-        解绑操作时，入参需要传入负载均衡实例执行解绑后所绑定的所有安全组；如果要解绑所有安全组，可不传此参数，或传入空数组。注意：内网负载均衡不支持绑定安全组。
+        解绑操作时，入参需要传入负载均衡实例执行解绑后所绑定的所有安全组；如果要解绑所有安全组，可不传此参数，或传入空数组。注意：内网 CLB 绑定 EIP 后，CLB 上的安全组对来自 EIP 的流量不生效，对来自内网 CLB 的流量生效。
 
         :param request: Request instance for SetLoadBalancerSecurityGroups.
         :type request: :class:`tencentcloud.clb.v20180317.models.SetLoadBalancerSecurityGroupsRequest`
@@ -1925,6 +2040,31 @@ class ClbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SetLoadBalancerStartStatus(self, request):
+        """启停负载均衡实例或者监听器。
+        本接口为异步接口，接口返回成功后，需以得到的 RequestID 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。
+        该功能正在内测中，如需使用，请通过[工单申请](https://console.cloud.tencent.com/workorder/category?level1_id=6&level2_id=163&source=0&data_title=%E8%B4%9F%E8%BD%BD%E5%9D%87%E8%A1%A1%20LB&step=1)。
+
+        :param request: Request instance for SetLoadBalancerStartStatus.
+        :type request: :class:`tencentcloud.clb.v20180317.models.SetLoadBalancerStartStatusRequest`
+        :rtype: :class:`tencentcloud.clb.v20180317.models.SetLoadBalancerStartStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SetLoadBalancerStartStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.SetLoadBalancerStartStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SetSecurityGroupForLoadbalancers(self, request):
         """绑定或解绑一个安全组到多个公网负载均衡实例。注意：内网负载均衡不支持绑定安全组。
 
